archmTau Computes Kendall's tau for Archimedean copulae,
archmRho computes Spearman's rho for Archimedean copulae,
archmTailCoeff computes tail dependence for Archimedean copulae,
archmTailPlot plots tail dependence for Archimedean copulae. }archmTau(alpha = NULL, type = archmList(), lower = 1.0e-10)
archmRho(alpha = NULL, type = archmList(), method = c("integrate2d", "adapt"),
error = 1.0e-5)
archmTailCoeff(alpha = NULL, type = archmList())
archmTailPlot(alpha = NULL, type = archmList(), tail = c("Upper", "Lower"))integrate2d
integration formula. A numeric value, by default error=1.0e-5.integrate."Upper" or "Lower" denoting
which of the two tails should be displayed. By default the upper
tail dependence will be considered."1" and "22". By default copula No. 1 will
be chosen."integrate2d" or "adapt". If the second
method is selected the contributed R package "adapt" is
pcopula returns a numeric matrix of probabilities
computed at grid positions x|y.
The function parchmCopula returns a numeric matrix with values
computed for the Archemedean copula.
The function darchmCopula returns a numeric matrix with values
computed for thedensity of the Archemedean copula.
The functions Phi* return a numeric vector with the values
computed from the Archemedean generator, its derivatives, or its
inverse.
The functions cK and {cKInv} return a numeric vector with the
values of the density and inverse for Archimedian copulae.## fCOPULA -
# getClass("fCOPULA")
## pcopula -
# The default Normal Copula:
# contour(pcopula())Run the code above in your browser using DataLab